aboutsummaryrefslogtreecommitdiff
path: root/sound
diff options
context:
space:
mode:
authorAndy Green <andy@openmoko.com>2009-03-02 18:51:56 +0000
committerAndy Green <agreen@octopus.localdomain>2009-03-02 18:51:56 +0000
commit81da012eb0fff1bc5f129202d0c12b1d63a7761a (patch)
tree3c2b6ca3b900b74e9784798722c581d5779bee33 /sound
parent560b9fed82e9fd5259ba611c9c6da449cf3f548b (diff)
rename-gta03-dropped-3d7k-new-moniker.patch
GTA03 project is dropped, long live Openmoko 3d7k project. This name was literally generated by picking the first character of the next four car license plates to pass by I am told. The should catch all GTA03 instances except the machine name. I registered a new machine name since the 3d7k is different from original GTA03, the machine number is 2120. Signed-off-by: Andy Green <andy@openmoko.com>
Diffstat (limited to 'sound')
-rw-r--r--sound/soc/s3c24xx/Kconfig4
-rw-r--r--sound/soc/s3c24xx/Makefile4
-rw-r--r--sound/soc/s3c24xx/om_3d7k_wm8753.c (renamed from sound/soc/s3c24xx/om_gta03_wm8753.c)130
3 files changed, 69 insertions, 69 deletions
diff --git a/sound/soc/s3c24xx/Kconfig b/sound/soc/s3c24xx/Kconfig
index 1ed87482b42..98816524992 100644
--- a/sound/soc/s3c24xx/Kconfig
+++ b/sound/soc/s3c24xx/Kconfig
@@ -52,13 +52,13 @@ config SND_S3C24XX_SOC_NEO1973_GTA02_WM8753
Say Y if you want to add support for SoC audio on neo1973 gta02
with the WM8753 codec
-config SND_S3C24XX_SOC_OM_GTA03_WM8753
+config SND_S3C24XX_SOC_OM_3D7K_WM8753
tristate "SoC I2S Audio support for OM GTA03 - WM8753"
depends on SND_S3C24XX_SOC && MACH_OPENMOKO_GTA03
select SND_S3C64XX_SOC_I2S
select SND_SOC_WM8753
help
- Say Y if you want support for SoC audio on Openmoko GTA03
+ Say Y if you want support for SoC audio on Openmoko 3D7K
with the WM8753 codec.
config SND_S3C24XX_SOC_SMDK2443_WM9710
diff --git a/sound/soc/s3c24xx/Makefile b/sound/soc/s3c24xx/Makefile
index 08bd5874633..f464e25a25a 100644
--- a/sound/soc/s3c24xx/Makefile
+++ b/sound/soc/s3c24xx/Makefile
@@ -20,7 +20,7 @@ snd-soc-smdk2443-wm9710-objs := smdk2443_wm9710.o
snd-soc-ln2440sbc-alc650-objs := ln2440sbc_alc650.o
snd-soc-s3c24xx-uda134x-objs := s3c24xx_uda134x.o
snd-soc-neo1973-gta02-wm8753-objs := neo1973_gta02_wm8753.o
-snd-soc-om-gta03-wm8753-objs := om_gta03_wm8753.o
+snd-soc-om-3d7k-wm8753-objs := om_3d7k_wm8753.o
snd-soc-smdk6410-wm8731-objs := smdk6410-wm8731.o
obj-$(CONFIG_SND_S3C24XX_SOC_JIVE_WM8750) += snd-soc-jive-wm8750.o
@@ -29,5 +29,5 @@ obj-$(CONFIG_SND_S3C24XX_SOC_SMDK2443_WM9710) += snd-soc-smdk2443-wm9710.o
obj-$(CONFIG_SND_S3C24XX_SOC_LN2440SBC_ALC650) += snd-soc-ln2440sbc-alc650.o
obj-$(CONFIG_SND_S3C24XX_SOC_S3C24XX_UDA134X) += snd-soc-s3c24xx-uda134x.o
obj-$(CONFIG_SND_S3C24XX_SOC_NEO1973_GTA02_WM8753) += snd-soc-neo1973-gta02-wm8753.o
-obj-$(CONFIG_SND_S3C24XX_SOC_OM_GTA03_WM8753) += snd-soc-om-gta03-wm8753.o
+obj-$(CONFIG_SND_S3C24XX_SOC_OM_3D7K_WM8753) += snd-soc-om-3d7k-wm8753.o
obj-$(CONFIG_SND_S3C64XX_SOC_SMDK6410_WM8731) += snd-soc-smdk6410-wm8731.o
diff --git a/sound/soc/s3c24xx/om_gta03_wm8753.c b/sound/soc/s3c24xx/om_3d7k_wm8753.c
index 8df3c7581c1..8a823f12109 100644
--- a/sound/soc/s3c24xx/om_gta03_wm8753.c
+++ b/sound/soc/s3c24xx/om_3d7k_wm8753.c
@@ -1,5 +1,5 @@
/*
* om_gta03_wm8753.c -- SoC audio for GTA03
*
* Based on neo1973_gta02_wm8753
*
@@ -48,9 +48,9 @@
#define NEO_CAPTURE_BLUETOOTH 8
#define NEO_STEREO_TO_HANDSET_SPK 9
-static struct snd_soc_card om_gta03;
+static struct snd_soc_card om_3d7K;
-static int om_gta03_hifi_hw_params(struct snd_pcm_substream *substream,
+static int om_3d7K_hifi_hw_params(struct snd_pcm_substream *substream,
struct snd_pcm_hw_params *params)
{
struct snd_soc_pcm_runtime *rtd = substream->private_data;
@@ -151,7 +151,7 @@ err:
return ret;
}
-static int om_gta03_hifi_hw_free(struct snd_pcm_substream *substream)
+static int om_3d7K_hifi_hw_free(struct snd_pcm_substream *substream)
{
struct snd_soc_pcm_runtime *rtd = substream->private_data;
struct snd_soc_dai *codec_dai = rtd->dai->codec_dai;
@@ -161,14 +161,14 @@ static int om_gta03_hifi_hw_free(struct snd_pcm_substream *substream)
}
/*
* GTA03 WM8753 HiFi DAI opserations.
*/
-static struct snd_soc_ops om_gta03_hifi_ops = {
- .hw_params = om_gta03_hifi_hw_params,
- .hw_free = om_gta03_hifi_hw_free,
+static struct snd_soc_ops om_3d7K_hifi_ops = {
+ .hw_params = om_3d7K_hifi_hw_params,
+ .hw_free = om_3d7K_hifi_hw_free,
};
-static int om_gta03_voice_hw_params(struct snd_pcm_substream *substream,
+static int om_3d7K_voice_hw_params(struct snd_pcm_substream *substream,
struct snd_pcm_hw_params *params)
{
struct snd_soc_pcm_runtime *rtd = substream->private_data;
@@ -214,7 +214,7 @@ static int om_gta03_voice_hw_params(struct snd_pcm_substream *substream,
return 0;
}
-static int om_gta03_voice_hw_free(struct snd_pcm_substream *substream)
+static int om_3d7K_voice_hw_free(struct snd_pcm_substream *substream)
{
struct snd_soc_pcm_runtime *rtd = substream->private_data;
struct snd_soc_dai *codec_dai = rtd->dai->codec_dai;
@@ -223,12 +223,12 @@ static int om_gta03_voice_hw_free(struct snd_pcm_substream *substream)
return snd_soc_dai_set_pll(codec_dai, WM8753_PLL2, 0, 0);
}
-static struct snd_soc_ops om_gta03_voice_ops = {
- .hw_params = om_gta03_voice_hw_params,
- .hw_free = om_gta03_voice_hw_free,
+static struct snd_soc_ops om_3d7K_voice_ops = {
+ .hw_params = om_3d7K_voice_hw_params,
+ .hw_free = om_3d7K_voice_hw_free,
};
-static int om_gta03_set_stereo_out(struct snd_kcontrol *kcontrol,
+static int om_3d7K_set_stereo_out(struct snd_kcontrol *kcontrol,
struct snd_ctl_elem_value *ucontrol)
{
struct snd_soc_codec *codec = snd_kcontrol_chip(kcontrol);
@@ -240,7 +240,7 @@ static int om_gta03_set_stereo_out(struct snd_kcontrol *kcontrol,
return 0;
}
-static int om_gta03_get_stereo_out(struct snd_kcontrol *kcontrol,
+static int om_3d7K_get_stereo_out(struct snd_kcontrol *kcontrol,
struct snd_ctl_elem_value *ucontrol)
{
struct snd_soc_codec *codec = snd_kcontrol_chip(kcontrol);
@@ -252,7 +252,7 @@ static int om_gta03_get_stereo_out(struct snd_kcontrol *kcontrol,
}
-static int om_gta03_set_gsm_out(struct snd_kcontrol *kcontrol,
+static int om_3d7K_set_gsm_out(struct snd_kcontrol *kcontrol,
struct snd_ctl_elem_value *ucontrol)
{
struct snd_soc_codec *codec = snd_kcontrol_chip(kcontrol);
@@ -264,7 +264,7 @@ static int om_gta03_set_gsm_out(struct snd_kcontrol *kcontrol,
return 0;
}
-static int om_gta03_get_gsm_out(struct snd_kcontrol *kcontrol,
+static int om_3d7K_get_gsm_out(struct snd_kcontrol *kcontrol,
struct snd_ctl_elem_value *ucontrol)
{
struct snd_soc_codec *codec = snd_kcontrol_chip(kcontrol);
@@ -275,7 +275,7 @@ static int om_gta03_get_gsm_out(struct snd_kcontrol *kcontrol,
return 0;
}
-static int om_gta03_set_gsm_in(struct snd_kcontrol *kcontrol,
+static int om_3d7K_set_gsm_in(struct snd_kcontrol *kcontrol,
struct snd_ctl_elem_value *ucontrol)
{
struct snd_soc_codec *codec = snd_kcontrol_chip(kcontrol);
@@ -287,7 +287,7 @@ static int om_gta03_set_gsm_in(struct snd_kcontrol *kcontrol,
return 0;
}
-static int om_gta03_get_gsm_in(struct snd_kcontrol *kcontrol,
+static int om_3d7K_get_gsm_in(struct snd_kcontrol *kcontrol,
struct snd_ctl_elem_value *ucontrol)
{
struct snd_soc_codec *codec = snd_kcontrol_chip(kcontrol);
@@ -298,7 +298,7 @@ static int om_gta03_get_gsm_in(struct snd_kcontrol *kcontrol,
return 0;
}
-static int om_gta03_set_headset_mic(struct snd_kcontrol *kcontrol,
+static int om_3d7K_set_headset_mic(struct snd_kcontrol *kcontrol,
struct snd_ctl_elem_value *ucontrol)
{
struct snd_soc_codec *codec = snd_kcontrol_chip(kcontrol);
@@ -310,7 +310,7 @@ static int om_gta03_set_headset_mic(struct snd_kcontrol *kcontrol,
return 0;
}
-static int om_gta03_get_headset_mic(struct snd_kcontrol *kcontrol,
+static int om_3d7K_get_headset_mic(struct snd_kcontrol *kcontrol,
struct snd_ctl_elem_value *ucontrol)
{
struct snd_soc_codec *codec = snd_kcontrol_chip(kcontrol);
@@ -321,7 +321,7 @@ static int om_gta03_get_headset_mic(struct snd_kcontrol *kcontrol,
return 0;
}
-static int om_gta03_set_handset_mic(struct snd_kcontrol *kcontrol,
+static int om_3d7K_set_handset_mic(struct snd_kcontrol *kcontrol,
struct snd_ctl_elem_value *ucontrol)
{
struct snd_soc_codec *codec = snd_kcontrol_chip(kcontrol);
@@ -334,7 +334,7 @@ static int om_gta03_set_handset_mic(struct snd_kcontrol *kcontrol,
return 0;
}
-static int om_gta03_get_handset_mic(struct snd_kcontrol *kcontrol,
+static int om_3d7K_get_handset_mic(struct snd_kcontrol *kcontrol,
struct snd_ctl_elem_value *ucontrol)
{
struct snd_soc_codec *codec = snd_kcontrol_chip(kcontrol);
@@ -345,7 +345,7 @@ static int om_gta03_get_handset_mic(struct snd_kcontrol *kcontrol,
return 0;
}
-static int om_gta03_set_handset_spk(struct snd_kcontrol *kcontrol,
+static int om_3d7K_set_handset_spk(struct snd_kcontrol *kcontrol,
struct snd_ctl_elem_value *ucontrol)
{
struct snd_soc_codec *codec = snd_kcontrol_chip(kcontrol);
@@ -358,7 +358,7 @@ static int om_gta03_set_handset_spk(struct snd_kcontrol *kcontrol,
return 0;
}
-static int om_gta03_get_handset_spk(struct snd_kcontrol *kcontrol,
+static int om_3d7K_get_handset_spk(struct snd_kcontrol *kcontrol,
struct snd_ctl_elem_value *ucontrol)
{
struct snd_soc_codec *codec = snd_kcontrol_chip(kcontrol);
@@ -408,32 +408,32 @@ static const struct snd_soc_dapm_route audio_map[] = {
{"ACIN", NULL, "ACOP"},
};
-static const struct snd_kcontrol_new wm8753_om_gta03_controls[] = {
+static const struct snd_kcontrol_new wm8753_om_3d7K_controls[] = {
SOC_SINGLE_EXT("DAPM Stereo Out Switch", 0, 0, 1, 0,
- om_gta03_get_stereo_out,
- om_gta03_set_stereo_out),
+ om_3d7K_get_stereo_out,
+ om_3d7K_set_stereo_out),
SOC_SINGLE_EXT("DAPM GSM Line Out Switch", 1, 0, 1, 0,
- om_gta03_get_gsm_out,
- om_gta03_set_gsm_out),
+ om_3d7K_get_gsm_out,
+ om_3d7K_set_gsm_out),
SOC_SINGLE_EXT("DAPM GSM Line In Switch", 2, 0, 1, 0,
- om_gta03_get_gsm_in,
- om_gta03_set_gsm_in),
+ om_3d7K_get_gsm_in,
+ om_3d7K_set_gsm_in),
SOC_SINGLE_EXT("DAPM Headset Mic Switch", 3, 0, 1, 0,
- om_gta03_get_headset_mic,
- om_gta03_set_headset_mic),
+ om_3d7K_get_headset_mic,
+ om_3d7K_set_headset_mic),
SOC_SINGLE_EXT("DAPM Handset Mic Switch", 4, 0, 1, 0,
- om_gta03_get_handset_mic,
- om_gta03_set_handset_mic),
+ om_3d7K_get_handset_mic,
+ om_3d7K_set_handset_mic),
SOC_SINGLE_EXT("DAPM Handset Spk Switch", 5, 0, 1, 0,
- om_gta03_get_handset_spk,
- om_gta03_set_handset_spk),
+ om_3d7K_get_handset_spk,
+ om_3d7K_set_handset_spk),
};
/*
* This is an example machine initialisation for a wm8753 connected to a
* neo1973 GTA02.
*/
-static int om_gta03_wm8753_init(struct snd_soc_codec *codec)
+static int om_3d7K_wm8753_init(struct snd_soc_codec *codec)
{
int i, err;
@@ -448,9 +448,9 @@ static int om_gta03_wm8753_init(struct snd_soc_codec *codec)
ARRAY_SIZE(wm8753_dapm_widgets));
/* add neo1973 gta02 specific controls */
- for (i = 0; i < ARRAY_SIZE(wm8753_om_gta03_controls); i++) {
+ for (i = 0; i < ARRAY_SIZE(wm8753_om_3d7K_controls); i++) {
err = snd_ctl_add(codec->card,
- snd_soc_cnew(&wm8753_om_gta03_controls[i],
+ snd_soc_cnew(&wm8753_om_3d7K_controls[i],
codec, NULL));
if (err < 0)
return err;
@@ -492,44 +492,44 @@ static struct snd_soc_dai bt_dai =
},
};
-static struct snd_soc_dai_link om_gta03_dai[] = {
+static struct snd_soc_dai_link om_3d7K_dai[] = {
{ /* Hifi Playback - for similatious use with voice below */
.name = "WM8753",
.stream_name = "WM8753 HiFi",
.cpu_dai = &s3c64xx_i2s_dai,
.codec_dai = &wm8753_dai[WM8753_DAI_HIFI],
- .init = om_gta03_wm8753_init,
- .ops = &om_gta03_hifi_ops,
+ .init = om_3d7K_wm8753_init,
+ .ops = &om_3d7K_hifi_ops,
},
{ /* Voice via BT */
.name = "Bluetooth",
.stream_name = "Voice",
.cpu_dai = &bt_dai,
.codec_dai = &wm8753_dai[WM8753_DAI_VOICE],
- .ops = &om_gta03_voice_ops,
+ .ops = &om_3d7K_voice_ops,
},
};
-static struct snd_soc_card om_gta03 = {
- .name = "om-gta03",
+static struct snd_soc_card om_3d7K = {
+ .name = "om-3d7K",
.platform = &s3c24xx_soc_platform,
- .dai_link = om_gta03_dai,
- .num_links = ARRAY_SIZE(om_gta03_dai),
+ .dai_link = om_3d7K_dai,
+ .num_links = ARRAY_SIZE(om_3d7K_dai),
};
-static struct snd_soc_device om_gta03_snd_devdata = {
- .card = &om_gta03,
+static struct snd_soc_device om_3d7K_snd_devdata = {
+ .card = &om_3d7K,
.codec_dev = &soc_codec_dev_wm8753,
};
-static struct platform_device *om_gta03_snd_device;
+static struct platform_device *om_3d7K_snd_device;
-static int __init om_gta03_init(void)
+static int __init om_3d7K_init(void)
{
int ret;
if (!machine_is_openmoko_gta03()) {
- printk(KERN_INFO "Only GTA03 supported by ASoC driver\n");
+ printk(KERN_INFO "Only 3D7K supported by ASoC driver\n");
return -ENODEV;
}
@@ -538,31 +538,31 @@ static int __init om_gta03_init(void)
if (ret)
return ret;
- om_gta03_snd_device = platform_device_alloc("soc-audio", 1);
- if (!om_gta03_snd_device)
+ om_3d7K_snd_device = platform_device_alloc("soc-audio", 1);
+ if (!om_3d7K_snd_device)
return -ENOMEM;
- platform_set_drvdata(om_gta03_snd_device, &om_gta03_snd_devdata);
- om_gta03_snd_devdata.dev = &om_gta03_snd_device->dev;
- ret = platform_device_add(om_gta03_snd_device);
+ platform_set_drvdata(om_3d7K_snd_device, &om_3d7K_snd_devdata);
+ om_3d7K_snd_devdata.dev = &om_3d7K_snd_device->dev;
+ ret = platform_device_add(om_3d7K_snd_device);
if (ret) {
- platform_device_put(om_gta03_snd_device);
+ platform_device_put(om_3d7K_snd_device);
return ret;
}
return ret;
}
-static void __exit om_gta03_exit(void)
+static void __exit om_3d7K_exit(void)
{
- platform_device_unregister(om_gta03_snd_device);
+ platform_device_unregister(om_3d7K_snd_device);
}
-module_init(om_gta03_init);
-module_exit(om_gta03_exit);
+module_init(om_3d7K_init);
+module_exit(om_3d7K_exit);
/* Module information */
MODULE_AUTHOR("Graeme Gregory, graeme@openmoko.org; Ben Dooks <ben@simtec.co.uk>");
-MODULE_DESCRIPTION("ALSA SoC WM8753 OM GTA03");
+MODULE_DESCRIPTION("ALSA SoC WM8753 OM 3D7K");
MODULE_LICENSE("GPL");
@@ -1,5 +1,5 @@
/*
- * om_gta03_wm8753.c -- SoC audio for GTA03
+ * om_3d7K_wm8753.c -- SoC audio for 3D7K
*
* Based on neo1973_gta02_wm8753
@@ -161,14 +161,14 @@ static int om_gta03_hifi_hw_free(struct snd_pcm_substream *substream)
}
/*
- * GTA03 WM8753 HiFi DAI opserations.
+ * 3D7K WM8753 HiFi DAI opserations.
*/